@@ -155,12 +155,6 @@ class H2OContext(object):
     def getConf(self):
         return self._conf
 
-    def setH2OLogLevel(self, level):
-        self._jhc.setH2OLogLevel(level)
-
-    def getH2OLogLevel(self):
-        return self._jhc.getH2OLogLevel()
-
     def asSparkFrame(self, h2oFrame, copyMetadata=True):
         """
         Transforms given H2OFrame to Spark DataFrame
